## Documentation

See the topics below for how to set up and use `instamatic`.

- [TEMController](tem_api.md)
- [Config](config.md)
- [Reading and writing image data](formats.md)
- [Setting up instamatic](setup.md)
- [Programs included](programs.md)
- [GUI and Module system](gui.md)
- [TVIPS module](tvips.md)

Use `pydoc` to access the full API reference: `pydoc -b instamatic`
